/************************************************************
* This file is part of the XDN Router project.
*
* XDN Router is a packet routing device to be used with
* a local XDN (XBee Distributed Network) configuration.
* It supports both core and edge routing modes.
* Copyright (C) 2008 Adam Shapiro, Cornell University
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
************************************************************/
/** \file
 * \brief Endian helper function declarations.
 *
 * This file contains declarations of helper functions
 * for switching between big and little endian. All
 * network data isbig endian, AVRs are a little endian
 * architecture.
 */

#ifndef __endian_h__
#define __endian_h__

#include <stdint.h>

/**
 * \brief 16-bit endian swap.
 *
 * This function swaps the endianness for
 * a 16-bit value (either bit to little, or
 * little to big) in-place.
 *
 * \param value is a pointer to the value to swap.
 */
inline void EndianSwap_16(uint16_t* value);

#endif
